@@ -23,10 +23,7 @@
  */
 
 #include <cstddef>
-#include <bits/stl_iterator_base_types.h>
-
-#include <cstddef>
-#include <bits/stl_iterator_base_types.h>
+#include <iterator>
 
 namespace wibble {
 
