@@ -4,7 +4,16 @@
 #include <wibble/exception.h>
 #include <fstream>
 #include <sys/stat.h>
+#include <unistd.h>
 #include <errno.h>
+#include <malloc.h> // alloca on win32 seems to live there
+
+#ifdef HAVE_CONFIG_H
+/* Conditionally include config.h so there is a way of enabling the fast
+ * Directory::isdir implementation if HAVE_STRUCT_DIRENT_D_TYPE is available
+ */
+#include <wibble/config.h>
+#endif
 
 namespace wibble {
 namespace sys {
@@ -24,6 +33,11 @@ std::auto_ptr<struct stat> stat(const std::string& pathname)
 }
 
 bool isDirectory(const std::string& pathname)
+{
+    return isdir(pathname);
+}
+
+bool isdir(const std::string& pathname)
 {
 	struct stat st;
 	if (::stat(pathname.c_str(), &st) == -1) {
@@ -40,6 +54,11 @@ bool access(const std::string &s, int m)
 	return ::access(s.c_str(), m) == 0;
 }
 
+bool exists(const std::string& file)
+{
+    return sys::fs::access(file, F_OK);
+}
+
 std::string abspath(const std::string& pathname)
 {
 	if (pathname[0] == '/')
@@ -89,7 +108,7 @@ std::string readFile( const std::string &file )
     in.seekg(0, std::ios::end);
     length = in.tellg();
     in.seekg(0, std::ios::beg);
-    char buffer[ length ];
+    char *buffer = (char *) alloca( length );
 
     in.read(buffer, length);
     return std::string( buffer, length );
@@ -103,10 +122,9 @@ void writeFile( const std::string &file, const std::string &data )
     out << data;
 }
 
-#ifdef POSIX
 bool deleteIfExists(const std::string& file)
 {
-	if (unlink(file.c_str()) != 0)
+	if (::unlink(file.c_str()) != 0)
 		if (errno != ENOENT)
 			throw wibble::exception::File(file, "removing file");
 		else
@@ -115,6 +133,40 @@ bool deleteIfExists(const std::string& file)
 		return true;
 }
 
+void renameIfExists(const std::string& src, const std::string& dst)
+{
+    int res = ::rename(src.c_str(), dst.c_str());
+    if (res < 0 && errno != ENOENT)
+        throw wibble::exception::System("moving " + src + " to " + dst);
+}
+
+void unlink(const std::string& fname)
+{
+    if (::unlink(fname.c_str()) < 0)
+        throw wibble::exception::File(fname, "cannot delete file");
+}
+
+void rmdir(const std::string& dirname)
+{
+    if (::rmdir(dirname.c_str()) < 0)
+        throw wibble::exception::System("cannot delete directory " + dirname);
+}
+
+void rmtree(const std::string& dir)
+{
+    Directory d(dir);
+    for (Directory::const_iterator i = d.begin(); i != d.end(); ++i)
+    {
+        if (*i == "." || *i == "..") continue;
+        if (d.isdir(i))
+            rmtree(str::joinpath(dir, *i));
+        else
+            unlink(str::joinpath(dir, *i));
+    }
+    rmdir(dir);
+}
+
+#ifdef POSIX
 Directory::const_iterator Directory::begin()
 {
 	DIR* dir = opendir(m_path.c_str());
@@ -148,6 +200,23 @@ bool access(const std::string &s, int m)
 }
 #endif
 
+bool Directory::isdir(const const_iterator& i) const
+{
+#ifdef HAVE_STRUCT_DIRENT_D_TYPE
+	if (i->d_type == DT_DIR)
+		return true;
+	if (i->d_type != DT_UNKNOWN)
+		return false;
+#endif
+	// No d_type, we'll need to stat
+	std::auto_ptr<struct stat> st = stat(wibble::str::joinpath(m_path, *i));
+	if (st.get() == 0)
+		return false;
+	if (S_ISDIR(st->st_mode))
+		return true;
+    return false;
+}
+
 }
 }
 }
