@@ -4,7 +4,7 @@
 /*
  * OO base class for process functions and child processes
  *
- * Copyright (C) 2003--2006  Enrico Zini <enrico@debian.org>
+ * Copyright (C) 2003--2010  Enrico Zini <enrico@debian.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -72,6 +72,22 @@ void setCoreSizeLimit(int value);
 /// Close stdin, stdout and stderr and detach from the tty
 void detachFromTTY();
 
+/**
+ * Call from main() if you intend to set a different process title later on
+ *
+ * On Linux, this function moves the environment to a different location to
+ * allow its memory to be reused for the process title
+ */
+void initproctitle(int argc, char **argv);
+
+/**
+ * Change the process title, overwriting the contents of argv
+ *
+ * This is currently only implemented for Linux: on other systems it does not
+ * do anything.
+ */
+void setproctitle(const std::string& title);
+
 }
 }
 }
